diff --git a/Resources.qrc b/Resources.qrc
index fa8b8520..222c5993 100644
--- a/Resources.qrc
+++ b/Resources.qrc
@@ -36,5 +36,6 @@
icons/cubeoximeter.png
icons/trophy.png
icons/bookmark.png
+ icons/help.png
diff --git a/mainwindow.h b/mainwindow.h
index 62e9bbee..97fdde4c 100644
--- a/mainwindow.h
+++ b/mainwindow.h
@@ -135,9 +135,6 @@ private slots:
*/
void on_action_Import_Data_triggered();
- //! \brief Selects the welcome page when it's clicked on
- void on_actionView_Welcome_triggered();
-
//! \brief Toggle Fullscreen (currently F11)
void on_action_Fullscreen_triggered();
@@ -250,6 +247,10 @@ private slots:
void on_recordsBox_linkClicked(const QUrl &arg1);
+ void on_helpButton_clicked();
+
+ void on_actionView_S_ummary_triggered();
+
private:
Ui::MainWindow *ui;
diff --git a/mainwindow.ui b/mainwindow.ui
index 8d418cd0..56d1003b 100644
--- a/mainwindow.ui
+++ b/mainwindow.ui
@@ -78,7 +78,7 @@
QTabWidget::North
- 0
+ 1
false
@@ -89,7 +89,29 @@
false
-
+
+
+ &Summary
+
+
+
+ 0
+
+
+ 0
+
+ -
+
+
+
+ about:blank
+
+
+
+
+
+
+
0
@@ -97,7 +119,7 @@
- &Summary
+ &Help Browser
@@ -213,13 +235,6 @@
- -
-
-
- Summary
-
-
-
-
@@ -399,9 +414,9 @@
0
- 0
+ -211
143
- 519
+ 524
@@ -528,8 +543,8 @@
- 64
- 64
+ 48
+ 48
@@ -568,8 +583,8 @@
- 64
- 64
+ 48
+ 48
@@ -597,8 +612,8 @@
- 64
- 64
+ 48
+ 48
@@ -626,8 +641,8 @@
- 64
- 64
+ 48
+ 48
@@ -661,8 +676,8 @@
- 64
- 64
+ 48
+ 48
@@ -679,6 +694,35 @@
+ -
+
+
+
+ 0
+ 0
+
+
+
+ Help
+
+
+
+ :/icons/help.png:/icons/help.png
+
+
+
+ 48
+ 48
+
+
+
+ Qt::ToolButtonTextUnderIcon
+
+
+ true
+
+
+
-
@@ -699,6 +743,7 @@
oximetryButton
summaryButton_2
importButton
+ helpButton
@@ -892,7 +937,7 @@
&View
-
+
@@ -1126,6 +1171,14 @@
F8
+
+
+ View S&ummary
+
+
+ F4
+
+
diff --git a/icons/help.png b/icons/help.png
new file mode 100644
index 00000000..10b8d03b
Binary files /dev/null and b/icons/help.png differ
diff --git a/mainwindow.cpp b/mainwindow.cpp
index 9a4af5bc..0f9cf350 100644
--- a/mainwindow.cpp
+++ b/mainwindow.cpp
@@ -120,8 +120,8 @@ MainWindow::MainWindow(QWidget *parent) :
ui->tabWidget->insertTab(1,daily,STR_TR_Daily);
- // Start with the Welcome Tab
- ui->tabWidget->setCurrentWidget(ui->welcome); // setting this to daily shows the cube during loading..
+ // Start with the Summary Tab
+ ui->tabWidget->setCurrentWidget(ui->summaryTab); // setting this to daily shows the cube during loading..
// Nifty Notification popups in System Tray (uses Growl on Mac)
if (QSystemTrayIcon::isSystemTrayAvailable() && QSystemTrayIcon::supportsMessages()) {
@@ -224,7 +224,7 @@ void MainWindow::Startup()
}
- ui->tabWidget->setCurrentWidget(ui->welcome);
+ ui->tabWidget->setCurrentWidget(ui->summaryTab);
if (daily) daily->ReloadGraphs();
if (overview) overview->ReloadGraphs();
qprogress->hide();
@@ -351,11 +351,6 @@ QMenu * MainWindow::CreateMenu(QString title)
return menu;
}
-void MainWindow::on_actionView_Welcome_triggered()
-{
- ui->tabWidget->setCurrentWidget(ui->welcome);
-}
-
void MainWindow::on_action_Fullscreen_triggered()
{
if (ui->action_Fullscreen->isChecked())
@@ -1004,7 +999,7 @@ void MainWindow::on_summaryButton_clicked()
html+="";
}
html+=htmlFooter();
- ui->webView->setHtml(html);
+ ui->summaryView->setHtml(html);
// QString file="qrc:/docs/index.html";
// QUrl url(file);
// ui->webView->setUrl(url);
@@ -1250,13 +1245,13 @@ void MainWindow::on_actionExp_ort_triggered()
void MainWindow::on_actionOnline_Users_Guide_triggered()
{
ui->webView->load(QUrl("http://sourceforge.net/apps/mediawiki/sleepyhead/index.php?title=SleepyHead_Users_Guide"));
- ui->tabWidget->setCurrentIndex(0);
+ ui->tabWidget->setCurrentWidget(ui->helpTab);
}
void MainWindow::on_action_Frequently_Asked_Questions_triggered()
{
ui->webView->load(QUrl("http://sourceforge.net/apps/mediawiki/sleepyhead/index.php?title=Frequently_Asked_Questions"));
- ui->tabWidget->setCurrentIndex(0);
+ ui->tabWidget->setCurrentWidget(ui->helpTab);
}
void MainWindow::PrintReport(gGraphView *gv,QString name, QDate date)
@@ -1950,7 +1945,7 @@ void MainWindow::keyPressEvent(QKeyEvent * event)
void MainWindow::on_summaryButton_2_clicked()
{
- ui->tabWidget->setCurrentWidget(ui->welcome);
+ ui->tabWidget->setCurrentWidget(ui->summaryTab);
on_summaryButton_clicked();
}
@@ -1979,3 +1974,13 @@ void MainWindow::on_recordsBox_linkClicked(const QUrl &linkurl)
}
}
+
+void MainWindow::on_helpButton_clicked()
+{
+ ui->tabWidget->setCurrentWidget(ui->helpTab);
+}
+
+void MainWindow::on_actionView_S_ummary_triggered()
+{
+ ui->tabWidget->setCurrentWidget(ui->summaryTab);
+}